# Generated by roxygen2: do not edit by hand

S3method(plot,taxodist_cluster)
S3method(plot,taxodist_ord)
S3method(print,taxodist_focal)
S3method(print,taxodist_path)
S3method(print,taxodist_result)
S3method(summary,taxodist_ord)
export(cache_info)
export(check_coverage)
export(clear_cache)
export(closest_relative)
export(compare_lineages)
export(distance_matrix)
export(filter_clade)
export(focal_distances)
export(get_lineage)
export(get_lineage_by_id)
export(get_taxonomicon_id)
export(is_member)
export(lineage_depth)
export(load_cache)
export(mrca)
export(save_cache)
export(shared_clades)
export(taxo_cluster)
export(taxo_distance)
export(taxo_heatmap)
export(taxo_ordinate)
export(taxo_path)
export(taxo_search)
importFrom(httr,GET)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(rvest,html_attr)
importFrom(rvest,html_nodes)
importFrom(rvest,html_text)
importFrom(rvest,read_html)
importFrom(stringr,str_extract)
importFrom(stringr,str_remove)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_trim)
