% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.taxodist_result}
\alias{print.taxodist_result}
\title{Print method for taxodist distance results}
\usage{
\method{print}{taxodist_result}(x, ...)
}
\arguments{
\item{x}{A list returned by \code{\link[=taxo_distance]{taxo_distance()}}.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns \code{x}. Called for side effects (printing).
}
\description{
Print method for taxodist distance results
}
