% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.taxodist_path}
\alias{print.taxodist_path}
\title{Print method for taxodist_path objects}
\usage{
\method{print}{taxodist_path}(x, ...)
}
\arguments{
\item{x}{A \code{taxodist_path} object from \code{\link[=taxo_path]{taxo_path()}}.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns \code{x}. Called for side effects (printing).
}
\description{
Print method for taxodist_path objects
}
