% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{summary.taxodist_ord}
\alias{summary.taxodist_ord}
\title{Summary method for taxodist_ord objects}
\usage{
\method{summary}{taxodist_ord}(object, ...)
}
\arguments{
\item{object}{A \code{taxodist_ord} object from \code{\link{taxo_ordinate}}.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns a data frame containing the eigenvalues and
variance explained by each dimension.
}
\description{
Prints a summary of the PCoA ordination, including the goodness-of-fit
and the proportion of variance explained by each principal coordinate.
}
