% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.taxodist_focal}
\alias{print.taxodist_focal}
\title{Print method for taxodist_focal objects}
\usage{
\method{print}{taxodist_focal}(x, ...)
}
\arguments{
\item{x}{A \code{taxodist_focal} object from \code{\link[=focal_distances]{focal_distances()}}.}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns \code{x}. Called for side effects (printing).
}
\description{
Print method for taxodist_focal objects
}
